aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/core/SkMallocPixelRef.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/core/SkMallocPixelRef.h')
-rw-r--r--include/core/SkMallocPixelRef.h83
1 files changed, 44 insertions, 39 deletions
diff --git a/include/core/SkMallocPixelRef.h b/include/core/SkMallocPixelRef.h
index bb07fa2dab..2e4c4e69eb 100644
--- a/include/core/SkMallocPixelRef.h
+++ b/include/core/SkMallocPixelRef.h
@@ -22,12 +22,10 @@ public:
* lifetime of the pixel storage buffer, as this pixelref will not try
* to delete it.
*
- * The pixelref will ref() the colortable (if not NULL).
- *
* Returns NULL on failure.
*/
- static SkMallocPixelRef* NewDirect(const SkImageInfo&, void* addr,
- size_t rowBytes, SkColorTable*);
+ static sk_sp<SkPixelRef> MakeDirect(const SkImageInfo&, void* addr,
+ size_t rowBytes, sk_sp<SkColorTable>);
/**
* Return a new SkMallocPixelRef, automatically allocating storage for the
@@ -39,22 +37,18 @@ public:
*
* Returns NULL on failure.
*/
- static SkMallocPixelRef* NewAllocate(const SkImageInfo& info,
- size_t rowBytes, SkColorTable*);
+ static sk_sp<SkPixelRef> MakeAllocate(const SkImageInfo&, size_t rowBytes, sk_sp<SkColorTable>);
/**
* Identical to NewAllocate, except all pixel bytes are zeroed.
*/
- static SkMallocPixelRef* NewZeroed(const SkImageInfo& info,
- size_t rowBytes, SkColorTable*);
+ static sk_sp<SkPixelRef> MakeZeroed(const SkImageInfo&, size_t rowBytes, sk_sp<SkColorTable>);
/**
* Return a new SkMallocPixelRef with the provided pixel storage,
* rowBytes, and optional colortable. On destruction, ReleaseProc
* will be called.
*
- * This pixelref will ref() the specified colortable (if not NULL).
- *
* If ReleaseProc is NULL, the pixels will never be released. This
* can be useful if the pixels were stack allocated. However, such an
* SkMallocPixelRef must not live beyond its pixels (e.g. by copying
@@ -63,10 +57,10 @@ public:
* Returns NULL on failure.
*/
typedef void (*ReleaseProc)(void* addr, void* context);
- static SkMallocPixelRef* NewWithProc(const SkImageInfo& info,
- size_t rowBytes, SkColorTable*,
- void* addr, ReleaseProc proc,
- void* context);
+ static sk_sp<SkPixelRef> MakeWithProc(const SkImageInfo& info,
+ size_t rowBytes, sk_sp<SkColorTable>,
+ void* addr, ReleaseProc proc,
+ void* context);
/**
* Return a new SkMallocPixelRef that will use the provided
@@ -74,27 +68,38 @@ public:
* The SkData will be ref()ed and on destruction of the PielRef,
* the SkData will be unref()ed.
*
- * This pixelref will ref() the specified colortable (if not NULL).
- *
* Returns NULL on failure.
*/
+ static sk_sp<SkPixelRef> MakeWithData(const SkImageInfo& info,
+ size_t rowBytes,
+ sk_sp<SkColorTable>,
+ sk_sp<SkData> data);
+
+#ifdef SK_SUPPORT_LEGACY_PIXELREFFACTORY
+ static SkMallocPixelRef* NewDirect(const SkImageInfo& info, void* addr,
+ size_t rowBytes, SkColorTable* ctable) {
+ return (SkMallocPixelRef*)MakeDirect(info, addr, rowBytes, sk_ref_sp(ctable)).release();
+ }
+ static SkMallocPixelRef* NewAllocate(const SkImageInfo& info, size_t rb, SkColorTable* ct) {
+ return (SkMallocPixelRef*)MakeAllocate(info, rb, sk_ref_sp(ct)).release();
+ }
+ static SkMallocPixelRef* NewZeroed(const SkImageInfo& info, size_t rowBytes, SkColorTable* ct) {
+ return (SkMallocPixelRef*)MakeZeroed(info, rowBytes, sk_ref_sp(ct)).release();
+ }
+ static SkMallocPixelRef* NewWithProc(const SkImageInfo& info,
+ size_t rowBytes, SkColorTable* ctable,
+ void* addr, ReleaseProc proc,
+ void* ctx) {
+ return (SkMallocPixelRef*)MakeWithProc(info, rowBytes, sk_ref_sp(ctable), addr, proc, ctx).release();
+ }
static SkMallocPixelRef* NewWithData(const SkImageInfo& info,
size_t rowBytes,
SkColorTable* ctable,
SkData* data);
+#endif
void* getAddr() const { return fStorage; }
- class PRFactory : public SkPixelRefFactory {
- public:
- SkPixelRef* create(const SkImageInfo&, size_t rowBytes, SkColorTable*) override;
- };
-
- class ZeroedPRFactory : public SkPixelRefFactory {
- public:
- SkPixelRef* create(const SkImageInfo&, size_t rowBytes, SkColorTable*) override;
- };
-
protected:
// The ownPixels version of this constructor is deprecated.
SkMallocPixelRef(const SkImageInfo&, void* addr, size_t rb, SkColorTable*,
@@ -107,18 +112,18 @@ protected:
private:
// Uses alloc to implement NewAllocate or NewZeroed.
- static SkMallocPixelRef* NewUsing(void*(*alloc)(size_t),
- const SkImageInfo&,
- size_t rowBytes,
- SkColorTable*);
-
- void* fStorage;
- SkColorTable* fCTable;
- size_t fRB;
- ReleaseProc fReleaseProc;
- void* fReleaseProcContext;
-
- SkMallocPixelRef(const SkImageInfo&, void* addr, size_t rb, SkColorTable*,
+ static sk_sp<SkPixelRef> MakeUsing(void*(*alloc)(size_t),
+ const SkImageInfo&,
+ size_t rowBytes,
+ sk_sp<SkColorTable>);
+
+ void* fStorage;
+ sk_sp<SkColorTable> fCTable;
+ size_t fRB;
+ ReleaseProc fReleaseProc;
+ void* fReleaseProcContext;
+
+ SkMallocPixelRef(const SkImageInfo&, void* addr, size_t rb, sk_sp<SkColorTable>,
ReleaseProc proc, void* context);
typedef SkPixelRef INHERITED;
@@ -39,22 +37,18 @@ public:
/**
- * Identical to NewAllocate, except all pixel bytes are zeroed.
+ * Identical to MakeAllocate, except all pixel bytes are zeroed.
*/